******************************************
*** Malaria Tanzania
*** August 2016
*** Ninja Klejnstrup, John Rand and Julie Buhl Wiggers [modifications, Sam Jones]
*** Individual estimates 
******************************************
	
	clear all
	set more off
	set matsize 10000
	graph set eps fontface Times

	use work\pfpr_final, clear
	keep id_districtNameMap pfpr02-pfpr15
	tempfile pfpr02 
	saveold `pfpr02',  replace

	use work\data_final_new, clear
    merge m:1 id_districtNameMap using `pfpr02'
	drop _merge

	drop if cohort < 2000 | cohort >= 2007
	
	egen junk = median(mothers_edu), by(id_hh year)
	replace mothers_edu = floor(junk) if mothers_edu==.
	egen junk1 = median(mothers_edu), by(id_village)
	replace mothers_edu = floor(junk1) if mothers_edu==.
	drop junk junk1
	
	egen lang_comp = rowmax(english_comp math swahili_comp)
	
	encode id_districtNameMap, g(district_num)
	encode region, g(region_num)
	quie foreach v in english_comp math swahili_comp lang_comp {
		noi dis "centering `v'"
		gen `v'_centered=.
		label var `v'_centered "centering by median/year"
		forvalues y=10/14 {
			forvalues a=7/14 {
				summ `v' if year==`y' & age==`a' [aw=weight_all], d
				replace `v'_centered = (`v'-r(p50)) if year==`y' & age==`a'
			}
		}
	}
	
	rename math math_comp
	quie foreach v in english math swahili lang {
		egen junk = rank(`v'_comp), by(cohort year) track
		egen junkx = max(junk), by(cohort year `v'_comp)
		egen junk1 = max(junk), by(cohort year)
		gen `v'_xtile = 100*junkx/junk1
		label var `v'_xtile "Cohort-year percentile"	
		drop junk junk1 junkx
	}
	rename math_comp math 

*** More variables

	gen onTime=0
	replace onTime=1 if age-grade<=7
	
	gen dy = district_num+(1000*year)
	gen dc = district_num+(1000*cohort)
	gen da = region_num+(1000*age)
	gen ry = region_num+(1000*year)
	gen rc = region_num+(1000*cohort)
	gen ra = region_num+(1000*age)
	gen yearnew1 = year
	replace yearnew1 = 10 if year==11
	gen dyearnew1 = district_num+(1000*yearnew1)
	gen ryearnew = region_num+(1000*yearnew)
	gen dc_trend=district_num*c.cohort

	gen e_dum = 1 if english==5
	replace e_dum = 0 if english<5&english!=.
	gen m_dum = 1 if math==7
	replace m_dum = 0 if math<7&math!=.
	gen s_dum = 1 if swahili==5
	replace s_dum = 0 if swahili<5&swahili!=. 

	gen hhid = (1000000*year)+id_hh												/* identify singletons */
	bys hhid: egen help=sum(1)
	g helpb=(cohort>2001&cohort<=2004)
    g helpa=(cohort>2004)
	bys hhid: egen help_before=max(helpb) 
	bys hhid: egen help_after=max(helpa) 

	tab help year

	gen trend=year-10
	
	gen pfpr0503_reduction=pfpr05-pfpr03

	drop if english_comp==. | swahili_comp==. | math==.
	
	gen migration_rate=.
	replace migration_rate=8.7 if id_regionNameOld=="Dodoma" 
	replace migration_rate=23 if id_regionNameOld=="Arusha" 
	replace migration_rate=10.8 if id_regionNameOld=="Kilimanjaro" 
	replace migration_rate=8.9 if id_regionNameOld=="Tanga" 
	replace migration_rate=22.4 if id_regionNameOld=="Morogoro" 
	replace migration_rate=34.9 if id_regionNameOld=="Pwani" 
	replace migration_rate=114.4 if id_regionNameOld=="Dar Es Salaam" 
	replace migration_rate=10.6 if id_regionNameOld=="Lindi" 
	replace migration_rate=5.0 if id_regionNameOld=="Mtwara" 
	replace migration_rate=6.6 if id_regionNameOld=="Ruvuma" 
	replace migration_rate=11.5 if id_regionNameOld=="Iringa" 
	replace migration_rate=11.4 if id_regionNameOld=="Mbeya" 
	replace migration_rate=12.5 if id_regionNameOld=="Singida" 
	replace migration_rate=26.3 if id_regionNameOld=="Tabora" 
	replace migration_rate=10.5 if id_regionNameOld=="Rukwa" 
	replace migration_rate=5.2 if id_regionNameOld=="Kigoma" 
	replace migration_rate=21.3 if id_regionNameOld=="Shinyanga" 
	replace migration_rate=8.5 if id_regionNameOld=="Kagera" 

	
*	clean cmpltdGrade
	
	rename cmpltdGrade cmpltdGrade_old
	egen cmpltdGrade = rowmax(grade dropout_class)
	replace cmpltdGrade = 0 if never==1
	replace cmpltdGrade = 8 if cmpltdGrade> 7 & cmpltdGrade!=.

* rename
	rename english_comp_centered english_ctd
	rename math_centered math_ctd
	rename swahili_comp_centered swahili_ctd
	rename lang_comp_centered lang_ctd
	
* center
	summ cmpltdGrade [aw=weight]
	gen cmpltdGrade_cen = cmpltdGrade - r(mean)
	
	summ inutero_pfpr if cmpltdGrade!=. [aw=weight]
	gen inutero_pfpr_cen = inutero_pfpr - r(mean)
	
* save

	compress
	save work/dataFinal, replace
	
	exit
	

