cd "C:\Users\jubu.eco\Dropbox\PhD\Malaria and cognitive development\Sam"
	clear all
	set more off
	use "work/dataFinal"
	
	/* check required ado filed are installed! */
	quie foreach ado in outreg2 reghdfe {
		capture which `ado'
		if _rc!=0 {
			dis as error "Please install `ado' ado files"
			exit
		}
	}
	
	global type ctd 
	
	global controls  female birthorder hh_size i.mothers_edu poor ultra lights_pop  /**/
	global icontrols female birthorder /*  */
	global fes age cohort
	global cluster vce(cluster id_village dc)
	
	local stripout = subinstr("$controls","i.","",.)
	egen rowmiss = rowmiss(`stripout')
	gen not_singleton = (help>1 & rowmiss==0)									/* correct sample for HH FE estimates [non-singleton households and no missing obs. on full set of hh controls] */	
	



**************************
* Table 1 - descriptives *
**************************

	preserve
	keep if pfpr00!=.
	duplicates drop district_num, force
	sum pfpr00, detail
	g pfpr00quart=1 if pfpr00<=r(p25)
	replace pfpr00quart=2 if pfpr00<=r(p50) & pfpr00>r(p25)
	replace pfpr00quart=3 if pfpr00<=r(p75) & pfpr00>r(p50)
	replace pfpr00quart=4 if pfpr00<=r(max) & pfpr00>r(p75)
	sum pfpr00, detail
	g pfpr95ptile=1 if pfpr00>=r(p95)
	replace pfpr95ptile=0 if pfpr95==.
	g pfpr5ptile=1 if pfpr00<r(p5)
	replace pfpr5ptile=0 if pfpr5==.
	tempfile quartile
	save `quartile', replace
	restore

	merge m:1 district_num using `quartile'
	drop _merge
	g pfpr_high=0
	replace pfpr_high=1 if pfpr00quart>2

	g mother_noedu=1 if mothers_edu==0
	replace mother_noedu=0 if mothers_edu==1 | mothers_edu==2 | mothers_edu==3

	preserve
keep if cohort<=2007 & cohort>=2000
foreach v in inutero_pfpr contemp_pfpr age english_ctd math_ctd swahili_ctd poor ultra neverenrolled enr_ans mother_noedu mother_someP mother_someS mother_postS hh_size birthorder {
drop if `v'==.
}


bysort pfpr_high: outreg2 using out\Tables\Table_1, excel replace sum(log) eqkeep(mean sd) keep(inutero_pfpr contemp_pfpr age female english_ctd math_ctd swahili_ctd cmpltdGrade poor ultra neverenrolled enr_ans mother_* hh_size birthorder lights_pop)

estpost ttest inutero_pfpr contemp_pfpr age female english_ctd math_ctd swahili_ctd cmpltdGrade poor ultra neverenrolled enr_ans mother_* hh_size birthorder lights_pop, by(pfpr_high)
estout using out\Tables\Table_1_diff.xls, cells("b(star fmt(3)) se(fmt(3))") replace
restore
	preserve
	keep if cohort<=2007 & cohort>=2000
	foreach v in inutero_pfpr contemp_pfpr age english_ctd math_ctd swahili_ctd poor ultra neverenrolled enr_ans mother_noedu mother_someP mother_someS mother_postS hh_size birthorder {
	drop if `v'==.
	}
	count if pfpr_high==0
	count if pfpr_high==1
	duplicates drop year id_*, force
	count if pfpr_high==0
	count if pfpr_high==1
	restore	
	
************************
* Table 2 - Main results
************************
	gen all = 1
	local id = 0
	quie foreach test in english math swahili {
	
		local nn = proper("`test'")
		local ++id
		if `id' ==1 local out replace
		
		/* naive model */
		noi reghdfe `test'_$type inutero_pfpr  if mothers_edu!=. [pw=weight_all], $cluster	a(all)
		outreg2 using "out/Tables\Table2", excel keep(inutero_pfpr) ctitle("`nn'")  nocons `out'
		
		
		/* model with controls */
		noi reghdfe `test'_$type inutero_pfpr $controls [pw=weight_all] , a($fes dy) $cluster	
		local out append
		outreg2 using "out/Tables\Table2", excel keep(inutero_pfpr) ctitle("`nn'")  nocons `out'
		
		/* model with HH FE (nb. singletons automatically removed) */
		noi reghdfe `test'_$type inutero_pfpr $icontrols [pw=weight_all] , a($fes hhid) $cluster
		outreg2 using "out/Tables\Table2", excel dec(3) keep (inutero_pfpr) ctitle("`nn'")  nocons `out' addtext(Household FE, Yes)
	}


************************
* Table 3 - robustness
************************

putexcel set out/Tables/Table3, modify
	putexcel A3=("Model") B3=("Description") C3=("Outcome") D3=("N")  E3=("Estimate") F3=("N")  G3=("Estimate")  ///
	A4=("(1)") B4=("Cohort-level results") C4=("Cohort average test score") ///
	A6=("(2)") B6=("Reduced cohorts") C6=("Individual centered test score") ///
	A8=("(3)") B8=("Reduced districts") C8=("Individual centered test score") ///
	A10=("(4)") B10=("Only youngest and oldest cohorts") C10=("Individual centered test score") ///
	            B12=("Compentency cutoff") ///
	A13=("(5)") B13=("Cutoff 1") C13=("Dummy variable (letters or higher=1)") ///
	A15=("(6)") B15=("Cutoff 2") C15=("Dummy variable (words or higher=1)") ///
	A17=("(7)") B17=("Cutoff 3") C17=("Dummy variable (paragraph or higher=1)") ///
	A19=("(8)") B19=("Cutoff 4") C19=("Dummy variable (story or higher=1)") ///
	A21=("(9)") B21=("Cutoff 5") C21=("Dummy variable (full competencies=1)") ///
	
	/* NB. pseduo-panel cohort analysis in separate do file */
	
	/* reduced cohorts */

	local id = 0
	quie foreach test in english math swahili {
		local nn = proper("`test'")
		local ++id
		if `id' ==1 local out replace
		
		noi reghdfe `test'_$type inutero_pfpr $controls if cohort > 2001 [pw=weight_all] , a($fes dy) $cluster			/* model with controls */
		outreg2 using "out/Tables\S4_Table", excel keep(inutero_pfpr) ctitle("`nn'")  nocons  `out'
		
		scalar red_cohort_beta_`test'=_b[inutero_pfpr]
		scalar red_cohort_se_`test'=_se[inutero_pfpr]
		scalar red_cohort_N_`test'=e(N)
		putexcel D6=(red_cohort_N_english) E6=(red_cohort_beta_english) E7=(red_cohort_se_english)
		
		local out append
		noi reghdfe `test'_$type inutero_pfpr $icontrols if cohort > 2001 [pw=weight_all] , a($fes hhid) $cluster	 	/* model with HH FE, without singletons */
		outreg2 using "out/Tables\S4_Table", excel dec(3) keep(inutero_pfpr) ctitle("`nn'")  nocons `out' addtext(Household FE, Yes)
		
		scalar red_cohort_beta_`test'_HH=_b[inutero_pfpr]
		scalar red_cohort_se_`test'_HH=_se[inutero_pfpr]
		scalar red_cohort_N_`test'_HH=e(N)
		putexcel F6=(red_cohort_N_english_HH) G6=(red_cohort_beta_english_HH) G7=(red_cohort_se_english_HH)
	}
	
	
	/* reduced districts */
	
	local id = 0
	quie foreach test in english math swahili {
		local nn = proper("`test'")
		local ++id
		if `id' ==1 local out replace
		
		noi reghdfe `test'_$type inutero_pfpr $controls if pfpr02<=pfpr00 [pw=weight_all] , a($fes dy) $cluster			/* model with controls */
		outreg2 using "out/Tables\S5_Table", excel keep(inutero_pfpr) ctitle("`nn'")  nocons `out'
		
		scalar red_district_beta_`test'=_b[inutero_pfpr]
		scalar red_district_se_`test'=_se[inutero_pfpr]
		scalar red_district_N_`test'=e(N)
		putexcel D8=(red_district_N_english) E8=(red_district_beta_english) E9=(red_district_se_english)
		
		local out append
		noi reghdfe `test'_$type inutero_pfpr $icontrols if pfpr02<=pfpr00 [pw=weight_all] , a($fes hhid) $cluster	 	/* model with HH FE, without singletons */
		outreg2 using "out/Tables\S5_Table", excel dec(3) keep (inutero_pfpr) ctitle("`nn'")  nocons `out' addtext(Household FE, Yes)
		
		scalar red_district_beta_`test'_HH=_b[inutero_pfpr]
		scalar red_district_se_`test'_HH=_se[inutero_pfpr]
		scalar red_district_N_`test'_HH=e(N)
		putexcel F8=(red_district_N_english_HH) G8=(red_district_beta_english_HH) G9=(red_district_se_english_HH)
	}
	
/* only young and old */

	local id = 0
	quie foreach test in english math swahili {
		local nn = proper("`test'")
		local ++id
		if `id' ==1 local out replace
		
		noi reghdfe `test'_$type inutero_pfpr $controls if (cohort <= 2001 | cohort >= 2005) [pw=weight_all] , a($fes dy) $cluster			/* model with controls */
		outreg2 using "out/Tables\S6_Table", excel keep(inutero_pfpr) ctitle("`nn'")  nocons `out'
		
		scalar youngOld_beta_`test'=_b[inutero_pfpr]
		scalar youngOld_se_`test'=_se[inutero_pfpr]
		scalar youngOld_N_`test'=e(N)
		putexcel D10=(youngOld_N_english) E10=(youngOld_beta_english) E11=(youngOld_se_english)
		
		local out append
		noi reghdfe `test'_$type inutero_pfpr $icontrols if (cohort <= 2001 | cohort >= 2005) [pw=weight_all] , a($fes hhid) $cluster	 	/* model with HH FE, without singletons */
		outreg2 using "out/Tables\S6_Table", excel dec(3) keep (inutero_pfpr) ctitle("`nn'")  nocons `out' addtext(Household FE, Yes)
		
		scalar youngOld_beta_`test'_HH=_b[inutero_pfpr]
		scalar youngOld_se_`test'_HH=_se[inutero_pfpr]
		scalar youngOld_N_`test'_HH=e(N)
		putexcel F10=(youngOld_N_english_HH) G10=(youngOld_beta_english_HH) G11=(youngOld_se_english_HH)
		
	}

	/* run through specific cut-offs of the raw measure */

		local id = 0
	quie foreach test in english_comp math swahili_comp {
	
	summ `test'
	local start = r(min)
	local end   = r(max)-1
	local id = 0
	quie forvalues level = `start'/`end' {
	
		gen cutoff_`level'_`test' = (`test' > `level')
		
		local nn = proper("`test'")
		local ++id
		if `id' ==1 local out replace
		
		
		noi reghdfe cutoff_`level'_`test' inutero_pfpr $controls [pw=weight_all] , a($fes dy) $cluster			/* model with controls */
		outreg2 using "out\Tables\S7_cutoffs_`test'", excel keep (inutero_pfpr) ctitle("`nn'")  nocons  `out'
		
		scalar cutoff`level'_beta_`test'=_b[inutero_pfpr]
		scalar cutoff`level'_se_`test'=_se[inutero_pfpr]
		scalar cutoff`level'_N_`test'=e(N)

		
		local out append
		noi reghdfe cutoff_`level'_`test' inutero_pfpr $icontrols [pw=weight_all] , a($fes hhid) $cluster	 	/* model with HH FE, without singletons */
		outreg2 using "out\Tables\S7_cutoffs_`test'", excel dec(3) keep (inutero_pfpr) ctitle("`nn'")  nocons `out' addtext(Household FE, Yes)
		
		scalar cutoff`level'_beta_`test'_HH=_b[inutero_pfpr]
		scalar cutoff`level'_se_`test'_HH=_se[inutero_pfpr]
		scalar cutoff`level'_N_`test'_HH=e(N)

		drop cutoff_`level'_`test'

	}	
		putexcel D13=(cutoff1_N_english_comp) E13=(cutoff1_beta_english_comp) E14=(cutoff1_se_english_comp)
		putexcel D15=(cutoff2_N_english_comp) E15=(cutoff2_beta_english_comp) E16=(cutoff2_se_english_comp)
		putexcel D17=(cutoff3_N_english_comp) E17=(cutoff3_beta_english_comp) E18=(cutoff3_se_english_comp)
		putexcel D19=(cutoff4_N_english_comp) E19=(cutoff4_beta_english_comp) E20=(cutoff4_se_english_comp)
		putexcel D21=(cutoff5_N_english_comp) E21=(cutoff5_beta_english_comp) E22=(cutoff5_se_english_comp)
		
		putexcel F13=(cutoff1_N_english_comp_HH) G13=(cutoff1_beta_english_comp_HH) G14=(cutoff1_se_english_comp_HH)
		putexcel F15=(cutoff2_N_english_comp_HH) G15=(cutoff2_beta_english_comp_HH) G16=(cutoff2_se_english_comp_HH)
		putexcel F17=(cutoff3_N_english_comp_HH) G17=(cutoff3_beta_english_comp_HH) G18=(cutoff3_se_english_comp_HH)
		putexcel F19=(cutoff4_N_english_comp_HH) G19=(cutoff4_beta_english_comp_HH) G20=(cutoff4_se_english_comp_HH)
		putexcel F21=(cutoff5_N_english_comp_HH) G21=(cutoff5_beta_english_comp_HH) G22=(cutoff5_se_english_comp_HH)
		
	}
*/

	************************
* Table 4 - Discussion: Only 7,8 and 9 year olds
************************

	local id = 0
	quie foreach test in english math swahili {
		local nn = proper("`test'")
		local ++id
		if `id' ==1 local out replace	
		
		noi reghdfe `test'_$type inutero_pfpr  $controls if (age<10)  [pw=weight_all] , $cluster a($fes dy)		/* model with controls */
		outreg2 using "out\Tables\Table_4", excel  ctitle("`nn'") keep(inutero_pfpr) nocons `out' addtext(Household FE, No)
		
		local out append
		noi reghdfe `test'_$type inutero_pfpr $icontrols if age<10 [pw=weight_all] , $cluster a($fes hhid)	 	/* model with HH FE, without singletons */
		outreg2 using "out\Tables\Table_4", excel dec(3) keep(inutero_pfpr) ctitle("`nn'")  nocons `out' addtext(Household FE, Yes)
	}
		
************************
* Appendix - Moving average in early childhood PfPR
************************

	/*egen upper = pctile(inutero_pfpr), p(95) by(year)
	egen lower = pctile(inutero_pfpr), p(5) by(year)
	gen junk = inutero_pfpr>upper | inutero_pfpr<lower
	egen outlier = max(junk), by(district_num)									/* excludes any district that ever falls above (below) 95th (5th) percentile of a given year's malaria risk distribution */
	drop junk
	summ outlier [aw=weight]*/
	
	**Calculate three year moving average
	preserve
		use work/pfpr_final, clear
		keep id_districtNameMap pfpr00- pfpr15
		foreach var of varlist pfpr00- pfpr15 {
			local name=substr("`var'",-2,.)
			rename `var' pfpr20`name'
		}
		reshape long pfpr, i(id_districtNameMap) j(cohort)
		encode id_districtNameMap, g(id)
		tsset id cohort
		sort id cohort
		g moving_birthyearPfPR=(L.pfpr+pfpr+F.pfpr)/3
		tempfile movingaverage
		save `movingaverage'
	restore
	merge m:1 id_districtNameMap cohort using `movingaverage', keep(match master) keepusing(moving_birthyearPfPR) 
	assert _merge==3
	drop _merge
	
	local id = 0
	quie foreach test in english math swahili {
		local nn = proper("`test'")
		local ++id
		if `id' ==1 local out replace

		noi reghdfe `test'_$type moving_birthyearPfPR $controls [pw=weight_all], $cluster a($fes dy)											/* 3-year average */
		outreg2 using "out/Tables\S1_Table", excel dec(3) keep(moving_birthyearPfPR) nocons addtext(Household FE, No) `out'
		
		local out append
		noi reghdfe `test'_$type moving_birthyearPfPR $icontrols [pw=weight_all], $cluster a($fes hhid)											/* 3-year average */
		outreg2 using "out/Tables\S1_Table", excel dec(3) keep(moving_birthyearPfPR) nocons addtext(Household FE, Yes) `out'

	}
	
	
************************
* Appendix - Table 2 with controls
***********************

	
	local id = 0
	quie foreach test in english math swahili {
	
		local nn = proper("`test'")
		local ++id
		if `id' ==1 local out replace
		
		/* naive model */
		noi reghdfe `test'_$type inutero_pfpr  if mothers_edu!=. [pw=weight_all], $cluster	a(all)						
		outreg2 using "out/Tables\S2_Table", excel  ctitle("`nn'")  nocons  `out'
		
		/* model with controls */
		noi reghdfe `test'_$type inutero_pfpr $controls [pw=weight_all] , a($fes dy) $cluster			
		local out append
		outreg2 using "out/Tables\S2_Table", excel  ctitle("`nn'")  nocons  `out'
		
		/* model with HH FE (nb. singletons automatically removed) */
		noi reghdfe `test'_$type inutero_pfpr $icontrols [pw=weight_all] , a($fes hhid) $cluster	 	
		outreg2 using "out/Tables\S2_Table", excel dec(3) keep (inutero_pfpr) ctitle("`nn'")  nocons `out' addtext(Household FE, Yes)
	}




*****************************************************************
* Results available on request: Exclude districts with IMCI implementation before 2000 *
*****************************************************************

	gen exclude_IMCI=1 if id_districtNameMap=="arusha" | id_districtNameMap=="handeni" | id_districtNameMap=="igunga" | id_districtNameMap=="kibaha" | id_districtNameMap=="kibondo" ///
		| id_districtNameMap=="kilosa" | id_districtNameMap=="kongwa" | id_districtNameMap=="korogwe" | id_districtNameMap=="lushoto" | id_districtNameMap=="masasi" | id_districtNameMap=="mpwapwa" ///
		| id_districtNameMap=="mufindi" | id_districtNameMap=="muheza" | id_districtNameMap=="newala" | id_districtNameMap=="ngara" | id_districtNameMap=="pangani" | id_districtNameMap=="rufiji" ///
		| id_districtNameMap=="sengerema" | id_districtNameMap=="tandahimba" | id_districtNameMap=="tanga" | id_districtNameMap=="temeke" 

	local id = 0
	quie foreach test in english math swahili {
		local nn = proper("`test'")
		local ++id
		if `id' ==1 local out replace
		
		noi reghdfe `test'_$type inutero_pfpr $controls if (exclude_IMCI!=1) [pw=weight_all], a($fes dy) $cluster		/* model with controls */
		outreg2 using "out/Tables\IMCIextra", excel keep (inutero_pfpr) ctitle("`nn'")  nocons `out'
		
		local out append
		noi reghdfe `test'_$type inutero_pfpr $icontrols if exclude_IMCI!=1 [pw=weight_all] , a($fes hhid) $cluster			/* model with HHH fixed effects */
		outreg2 using "out/Tables\IMCIextra", excel keep (inutero_pfpr) ctitle("`nn'")  nocons `out'
	}
	
	
*****************************************************************
* Results available on request: Exclude districts with high migration rates		    *
*****************************************************************

	preserve 
		duplicates drop id_regionNameOld, force
		sum migration_rate, detail
		gen migration_high=1 if migration_rate>r(p50)
		keep id_regionNameOld migration_high
		save migration, replace
	restore
	merge m:1 id_regionNameOld using migration
	assert _merge==3
	
	drop _merge
	local id = 0
	quie foreach test in english math swahili {
		local nn = proper("`test'")
		local ++id
		if `id' ==1 local out replace
			
		noi reghdfe `test'_$type inutero_pfpr $controls if (migration_high!=1) [pw=weight_all], a($fes dy) $cluster				/* model with controls */
		outreg2 using "out/Tables\MIGRATIONextra", excel keep (inutero_pfpr) ctitle("`nn'")  nocons `out'
			
		local out append
		noi reghdfe `test'_$type inutero_pfpr $icontrols  if migration_high!=1 [pw=weight_all] , a($fes hhid) $cluster				/* model with HHH fixed effects */
		outreg2 using "out/Tables\MIGRATIONextra", excel keep (inutero_pfpr) ctitle("`nn'")  nocons `out'
	}
	

	
	exit
